@@ -1,20 +1,18 @@
 import datetime
+import os
 
 import pymongo
 import pymysql
+from ForMark.ForLog import ForLog
+from ForMark.ForPath import get_root_path
+from ForMark.flask_session import Session
+from ForMark.model.foot import Foot
+from ForMark.model.session import Session as SessionDB
 from bson import ObjectId
 from flask import Flask, g, request, session
 from flask_cors import CORS
 from mongoengine import connect
 
-from ForMark.ForLog import ForLog
-from ForMark.ForPath import get_root_path
-from ForMark.flask_session import Session
-import os
-
-from ForMark.model.foot import Foot
-from ForMark.model.session import Session as SessionDB
-
 # 1.1.17
 pymysql.install_as_MySQLdb()
 
@@ -24,7 +22,9 @@ class ForApp():
                  log_folder=None, root_path=None,
                  need_before_request=True,
                  need_after_request=True,
-                 page_size=10
+                 page_size=10,
+                 static_folder='/static',
+                 static_url_path='static'
                  ):
         self.import_name = import_name
         self.log_folder = log_folder
@@ -36,7 +36,7 @@ class ForApp():
         # 初始化日志
         ForLog(os.path.join(self.root_path, log_folder))
 
-        app = Flask(__name__)
+        app = Flask(__name__, static_folder=static_folder, static_url_path=static_url_path)
         CORS(app, supports_credentials=True)  # 设置跨域
         # json支持中文显示
         app.config['JSON_AS_ASCII'] = False
