@@ -14,18 +14,18 @@ def permission_check(authority, category=None):
         @wraps(func)
         def inner(*args, **kwargs):
             user_id = session.get('user_id', None)
-            # print("用户id", user_id)
-            # if not user_id:
-            #     if authority == NO_LOGIN:
-            #         g.user = None
-            #         return func(*args, **kwargs)
-            #     return jsonify_fail(code=10008)
-            # user = User.objects(id=user_id).first()
-            # if not user:
-            #     return jsonify_fail(code=10008)
-            # if authority < user.authority:
-            #     return jsonify_fail(code=10008)
-            # g.user = user
+            print("用户id", user_id)
+            if not user_id:
+                if authority == NO_LOGIN:
+                    g.user = None
+                    return func(*args, **kwargs)
+                return jsonify_fail(code=10008)
+            user = User.objects(id=user_id).first()
+            if not user:
+                return jsonify_fail(code=10008)
+            if authority < user.authority:
+                return jsonify_fail(code=10008)
+            g.user = user
             return func(*args, **kwargs)
 
         return inner
